# NotDB Viewer
Simple viewer for NotDB Databases

## Installation
#### PIP
```
pip install notdb-viewer
```

## Quick Start
```bash
notdb_viewer db.ndb
```
it will ask you for a port (default port is 5000)

* [NotDB Docs](https://github.com/nawafalqari/NotDB#readme)